import { defineProperty as _defineProperty } from './_virtual/_rollupPluginBabelHelpers.mjs';
import { UmiError } from '@metaplex-foundation/umi';

/** @category Errors */
class DataViewSerializerError extends UmiError {
  constructor(message, cause) {
    super(message, 'plugin', 'DataView Serializer', cause);
    _defineProperty(this, "name", 'DataViewSerializerError');
  }
}
class OperationNotSupportedError extends DataViewSerializerError {
  constructor(operation) {
    super(`The operation [${operation}] is ` + `not supported by the DataView Serializer.`);
    _defineProperty(this, "name", 'OperationNotSupportedError');
  }
}
class DeserializingEmptyBufferError extends DataViewSerializerError {
  constructor(serializer) {
    super(`Serializer [${serializer}] cannot deserialize empty buffers.`);
    _defineProperty(this, "name", 'DeserializingEmptyBufferError');
  }
}
class NotEnoughBytesError extends DataViewSerializerError {
  constructor(serializer, expected, actual) {
    super(`Serializer [${serializer}] expected ${expected} bytes, got ${actual}.`);
    _defineProperty(this, "name", 'NotEnoughBytesError');
  }
}
class NumberOutOfRangeError extends DataViewSerializerError {
  constructor(serializer, min, max, actual) {
    super(`Serializer [${serializer}] expected number to be between ${min} and ${max}, got ${actual}.`);
    _defineProperty(this, "name", 'NumberOutOfRangeError');
  }
}

export { DataViewSerializerError, DeserializingEmptyBufferError, NotEnoughBytesError, NumberOutOfRangeError, OperationNotSupportedError };
//# sourceMappingURL=errors.mjs.map
